# Copyright (c) 2014  Kontron Europe GmbH
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA

# Entity ID assignments
ENTITY_ID_CPU = 0x03
ENTITY_ID_BASEBOARD = 0x07
ENTITY_ID_POWER_MODULE = 0x0a
ENTITY_ID_COOLING_UNIT = 0x1e
ENTITY_ID_AIR_INLET = 0x37
ENTITY_ID_DCMI_AIR_INLET = 0x40
ENTITY_ID_DCMI_CPU = 0x41
ENTITY_ID_DCMI_BASEBOARD = 0x42
ENTITY_ID_PICMG_FRONT_BOARD = 0xa0
ENTITY_ID_PICMG_REAR_TRANSITION_MODULE = 0xc0
ENTITY_ID_PICMG_ADVANCED_MC = 0xc1
ENTITY_ID_PICMG_MICROTCA_CARRIER_HUB = 0xc2
ENTITY_ID_PICMG_SHELF_MANAGEMENT_CONTROLLER = 0xf0
ENTITY_ID_PICMG_FILTRATION_UNIT = 0xf1
ENTITY_ID_PICMG_SHELF_FRU_INFORMATION = 0xf2
